==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/players/mplayer/mplayerconfigwidget.h <==
#ifndef MPLAYERCONFIGWIDGET_H
#define MPLAYERCONFIGWIDGET_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <appconfiggroupwidget.h>

class QCheckBox;
class KComboBox;
class KIntSpinBox;
class KURLRequester;

namespace SubtitleComposer
{
	class MPlayerConfigWidget : public AppConfigGroupWidget
	{
		Q_OBJECT

		public:

			MPlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent=0 );
			~MPlayerConfigWidget();

			virtual void setControlsFromConfig();
			virtual void setConfigFromControls();

		private:

			QCheckBox* m_frameDropCheckBox;
			QCheckBox* m_hardFrameDropCheckBox;
			KComboBox* m_videoOutputComboBox;
			QCheckBox* m_videoOutputCheckBox;
			KComboBox* m_audioOutputComboBox;
			KIntSpinBox* m_avsyncSpinBox;
			QCheckBox* m_volumeNormalizationCheckBox;
			QCheckBox* m_avsyncCheckBox;
			QCheckBox* m_audioOutputCheckBox;
			KURLRequester* m_pathUrlRequester;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/players/mplayer/mplayerconfigwidget.h <==
#ifndef MPLAYERCONFIGWIDGET_H
#define MPLAYERCONFIGWIDGET_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <appconfiggroupwidget.h>

class QCheckBox;
class KComboBox;
class KIntSpinBox;
class KURLRequester;

namespace SubtitleComposer
{
	class MPlayerConfigWidget : public AppConfigGroupWidget
	{
		Q_OBJECT

		public:

			MPlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent=0 );
			~MPlayerConfigWidget();

			virtual void setControlsFromConfig();
			virtual void setConfigFromControls();

		private:

			QCheckBox* m_frameDropCheckBox;
			QCheckBox* m_hardFrameDropCheckBox;
			KComboBox* m_videoOutputComboBox;
			QCheckBox* m_videoOutputCheckBox;
			KComboBox* m_audioOutputComboBox;
			KIntSpinBox* m_avsyncSpinBox;
			QCheckBox* m_volumeNormalizationCheckBox;
			QCheckBox* m_avsyncCheckBox;
			QCheckBox* m_audioOutputCheckBox;
			KURLRequester* m_pathURLRequester;
	};
}

#endif
